import pandas

with open('rad_wow_human_auto.csv', newline='') as f:
	df = pandas.read_csv(f, header=[0, 1], index_col=0)

df = df.loc[:, [('Human'), ('Valid Seen'), ('Valid Unseen'), ('My Valid Seen'), ('My Valid Unseen')]]

# https://stackoverflow.com/a/47891276/1959707
for col in df['Human']:
	df.loc[:, ('Human', col)] = df['Human'][col].str.rstrip('%').astype('float') / 100.0

df['Human'].astype(float).corrwith(df['Valid Seen'].astype(float), axis=0, drop=True)

df1 = df.copy()

vs1 = df['Valid Seen'].loc[:, [('PPL'), ('F1'), ('Knowledge F1')]]
vs2 = df['My Valid Seen'].rename(columns={'Rare Dialog Word F1': 'Rare Word F1'}).loc[:, 'Rare Word F1']
vs = pandas.concat([vs1, vs2], axis=1)

vu1 = df['Valid Unseen'].loc[:, [('PPL'), ('F1'), ('Knowledge F1')]]
vu2 = df['My Valid Unseen'].rename(columns={'Rare Dialog Word F1': 'Rare Word F1'}).loc[:, 'Rare Word F1']
vu = pandas.concat([vu1, vu2], axis=1)

df1 = pandas.concat([df['Human'], vs, vu], axis=1, keys=['Human', 'Valid Seen', 'Valid Unseen'])

hvs = df1.corr().loc['Human', 'Valid Seen'][:-1]
hvu = df1.corr().loc['Human', 'Valid Unseen'][:-1]

import seaborn as sb
import matplotlib.pyplot as plt

sb.set_theme(style="white")

def save_plot_hm(dframe, fname):
	plt.figure(figsize=(5, 2))
	cmap = sb.diverging_palette(230, 20, as_cmap=True)
	hm = sb.heatmap(dframe, cmap=cmap, annot=True, linewidths=.5, cbar=False, annot_kws={"fontsize":9})
	hm.xaxis.tick_top()
	hm.xaxis.set_label_position('top')
	plt.tick_params(axis='both', which='major', labelsize=10, labelbottom = False, bottom=False, top = False, labeltop=True)
	plt.yticks(rotation=0)
	hm.autoscale(enable=True)
	plt.savefig(f'{fname}.pdf', bbox_inches='tight',dpi=100)

save_plot_hm(hvs, 'human_auto_valid_seen')
save_plot_hm(hvu, 'human_auto_valid_unseen')